about summary refs log tree commit diff stats
path: root/apidocs/python
diff options
context:
space:
mode:
authorJames Booth <boothj5@gmail.com>2016-08-10 20:45:14 +0100
committerJames Booth <boothj5@gmail.com>2016-08-10 20:45:14 +0100
commita948d741d987b7c94487ec379484c7557c1ea98e (patch)
tree691e9547bd47c3185702e17a4017ad4473831f7f /apidocs/python
parentb64a9c3d6d99eabdcb3005b009cf034c348bbb03 (diff)
downloadprofani-tty-a948d741d987b7c94487ec379484c7557c1ea98e.tar.gz
Rename plugin jid arguments
Diffstat (limited to 'apidocs/python')
-rw-r--r--apidocs/python/src/plugin.py60
1 files changed, 30 insertions, 30 deletions
diff --git a/apidocs/python/src/plugin.py b/apidocs/python/src/plugin.py
index ff70b4a3..a9dac2cd 100644
--- a/apidocs/python/src/plugin.py
+++ b/apidocs/python/src/plugin.py
@@ -119,13 +119,13 @@ def prof_post_chat_message_send(barejid, message):
     pass
 
 
-def prof_pre_room_message_display(room, nick, message):
+def prof_pre_room_message_display(barejid, nick, message):
     """Called before a chat room message is displayed
 
     :param room: Jabber ID of the room
     :param nick: nickname of message sender
     :param message: the received message
     :type room: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
     :return: the new message to display, or ``None`` to preserve the original message 
@@ -134,25 +134,25 @@ def prof_pre_room_message_display(room, nick, message):
     pass
 
 
-def prof_post_room_message_display(room, nick, message):
+def prof_post_room_message_display(barejid, nick, message):
     """Called after a chat room message is displayed
 
     :param room: Jabber ID of the room
     :param nick: nickname of the message sender 
     :param message: the received message
     :type room: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
     """
     pass
 
 
-def prof_pre_room_message_send(room, message):
+def prof_pre_room_message_send(barejid, message):
     """Called before a chat room message is sent
 
     :param room: Jabber ID of the room
     :param message: the message to be sent
     :type room: str or unicode
     :type message: str or unicode
     :return: the new message to send, or ``None`` to preserve the original message 
     :rtype: str or unicode
@@ -160,25 +160,25 @@ def prof_pre_room_message_send(room, message):
     pass
 
 
-def prof_post_room_message_send(room, message):
+def prof_post_room_message_send(barejid, message):
     """Called after a chat room message has been sent
 
     :param room: Jabber ID of the room
     :param message: the sent message
     :type room: str or unicode
     :type message: str or unicode
     """
     pass
 
 
-def prof_on_room_history_message(room, nick, message, timestamp):
+def prof_on_room_history_message(barejid, nick, message, timestamp):
     """Called when the server sends a chat room history message
 
     :param room: Jabber ID of the room
     :param nick: nickname of the message sender
     :param message: the message to be sent
     :param timestamp: time the message was originally sent to the room, in ISO8601 format
     :type room: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
     :type timestamp: str or unicode
@@ -186,13 +186,13 @@ def prof_on_room_history_message(room, nick, message, timestamp):
     pass
 
 
-def prof_pre_priv_message_display(room, nick, message):
+def prof_pre_priv_message_display(barejid, nick, message):
     """Called before a private chat room message is displayed
 
     :param room: Jabber ID of the room
     :param nick: nickname of message sender
     :param message: the received message
     :type room: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
     :return: the new message to display, or ``None`` to preserve the original message 
@@ -201,26 +201,26 @@ def prof_pre_priv_message_display(room, nick, message):
     pass
 
 
-def prof_post_priv_message_display(room, nick, message):
+def prof_post_priv_message_display(barejid, nick, message):
     """Called after a private chat room message is displayed
 
     :param room: Jabber ID of the room
     :param nick: nickname of the message sender 
     :param message: the received message
     :type room: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
     """
     pass
 
 
-def prof_pre_priv_message_send(room, nick, message):
+def prof_pre_priv_message_send(barejid, nick, message):
     """Called before a private chat room message is sent
 
     :param room: Jabber ID of the room
     :param nick: nickname of message recipient
     :param message: the message to be sent
     :type room: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
     :return: the new message to send, or ``None`` to preserve the original message 
@@ -229,13 +229,13 @@ def prof_pre_priv_message_send(room, nick, message):
     pass
 
 
-def prof_post_priv_message_send(room, nick, message):
+def prof_post_priv_message_send(barejid, nick, message):
     """Called after a private chat room message has been sent
 
     :param room: Jabber ID of the room
     :param nick: nickname of the message recipient
     :param message: the sent message
     :type room: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
     """
@@ -347,10 +347,10 @@ def prof_on_chat_win_focus(barejid):
     pass
 
 
-def prof_on_room_win_focus(room):
+def prof_on_room_win_focus(barejid):
     """Called when a chat room window is focussed
 
     :param room: Jabber ID of the room
     :type room: str or unicode
     """
     pass
@@ -119,13 +119,13 @@ def prof_post_chat_message_send(barejid, message):
     """Called before a chat room message is displayed
 
-    :param room: Jabber ID of the room
+    :param barejid: Jabber ID of the room
     :param nick: nickname of message sender
     :param message: the received message
@@ -119,13 +119,13 @@ def prof_post_chat_message_send(barejid, message):
     :param nick: nickname of message sender
     :param message: the received message
-    :type room: str or unicode
+    :type barejid: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
@@ -134,25 +134,25 @@ def prof_pre_room_message_display(room, nick, message):
     """Called after a chat room message is displayed
 
-    :param room: Jabber ID of the room
+    :param barejid: Jabber ID of the room
     :param nick: nickname of the message sender 
     :param message: the received message
@@ -134,25 +134,25 @@ def prof_pre_room_message_display(room, nick, message):
     :param nick: nickname of the message sender 
     :param message: the received message
-    :type room: str or unicode
+    :type barejid: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
@@ -134,25 +134,25 @@ def prof_pre_room_message_display(room, nick, message):
     """Called before a chat room message is sent
 
-    :param room: Jabber ID of the room
+    :param barejid: Jabber ID of the room
     :param message: the message to be sent
@@ -134,25 +134,25 @@ def prof_pre_room_message_display(room, nick, message):
     :param message: the message to be sent
-    :type room: str or unicode
+    :type barejid: str or unicode
     :type message: str or unicode
     :return: the new message to send, or ``None`` to preserve the original message 
@@ -160,25 +160,25 @@ def prof_pre_room_message_send(room, message):
     """Called after a chat room message has been sent
 
-    :param room: Jabber ID of the room
+    :param barejid: Jabber ID of the room
     :param message: the sent message
@@ -160,25 +160,25 @@ def prof_pre_room_message_send(room, message):
     :param message: the sent message
-    :type room: str or unicode
+    :type barejid: str or unicode
     :type message: str or unicode
     """
@@ -160,25 +160,25 @@ def prof_pre_room_message_send(room, message):
     """Called when the server sends a chat room history message
 
-    :param room: Jabber ID of the room
+    :param barejid: Jabber ID of the room
     :param nick: nickname of the message sender
     :param message: the message to be sent
@@ -160,25 +160,25 @@ def prof_pre_room_message_send(room, message):
     :param message: the message to be sent
     :param timestamp: time the message was originally sent to the room, in ISO8601 format
-    :type room: str or unicode
+    :type barejid: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
@@ -186,13 +186,13 @@ def prof_on_room_history_message(room, nick, message, timestamp):
     """Called before a private chat room message is displayed
 
-    :param room: Jabber ID of the room
+    :param barejid: Jabber ID of the room
     :param nick: nickname of message sender
     :param message: the received message
@@ -186,13 +186,13 @@ def prof_on_room_history_message(room, nick, message, timestamp):
     :param nick: nickname of message sender
     :param message: the received message
-    :type room: str or unicode
+    :type barejid: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
@@ -201,26 +201,26 @@ def prof_pre_priv_message_display(room, nick, message):
     """Called after a private chat room message is displayed
 
-    :param room: Jabber ID of the room
+    :param barejid: Jabber ID of the room
     :param nick: nickname of the message sender 
     :param message: the received message
@@ -201,26 +201,26 @@ def prof_pre_priv_message_display(room, nick, message):
     :param nick: nickname of the message sender 
     :param message: the received message
-    :type room: str or unicode
+    :type barejid: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
@@ -201,26 +201,26 @@ def prof_pre_priv_message_display(room, nick, message):
     """Called before a private chat room message is sent
 
-    :param room: Jabber ID of the room
+    :param barejid: Jabber ID of the room
     :param nick: nickname of message recipient
     :param message: the message to be sent
@@ -201,26 +201,26 @@ def prof_pre_priv_message_display(room, nick, message):
     :param nick: nickname of message recipient
     :param message: the message to be sent
-    :type room: str or unicode
+    :type barejid: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
@@ -229,13 +229,13 @@ def prof_pre_priv_message_send(room, nick, message):
     """Called after a private chat room message has been sent
 
-    :param room: Jabber ID of the room
+    :param barejid: Jabber ID of the room
     :param nick: nickname of the message recipient
     :param message: the sent message
@@ -229,13 +229,13 @@ def prof_pre_priv_message_send(room, nick, message):
     :param nick: nickname of the message recipient
     :param message: the sent message
-    :type room: str or unicode
+    :type barejid: str or unicode
     :type nick: str or unicode
     :type message: str or unicode
@@ -347,10 +347,10 @@ def prof_on_chat_win_focus(barejid):
     """Called when a chat room window is focussed
 
-    :param room: Jabber ID of the room
-    :type room: str or unicode
+    :param barejid: Jabber ID of the room
+    :type barejid: str or unicode
     """
     pass